@@ -45,6 +45,10 @@ def get_user(rmine, userdata):
 def print_issue(rmine, issue, verbose=False, oneline=False):
     """Print out a redmine issue object."""
 
+    # handle unauth issues -- github #20
+    if issue.id == 0:
+        print('Unauthorized to view this issue')
+        return
     # handle oneline printing
     if oneline:
         print('%s %s %s %s %s %s' % (issue.id, issue.project.name,
@@ -74,21 +78,49 @@ def print_issue(rmine, issue, verbose=False, oneline=False):
         except ResourceAttrError:
             pass
         print('updated_on:  %s' % issue.updated_on)
-        print('description:\n')
-        print(issue.description)
+        if hasattr(issue, 'description'):
+            print('description:\n')
+            print(issue.description)
         print('----')
         for relation in issue.relations:
-            relish = rmine.issue.get(relation.issue_to_id)
-            print('%s %s - %s #%s: %s') % (relation.relation_type,
-                                           relish.project.name,
-                                           relish.tracker.name,
-                                           relish.id,
-                                           relish.subject)
+            # Get the verb right for blocking relationship
+            reltype = relation.relation_type
+            if relation.issue_id != issue.id:
+                if relation.relation_type == 'blocks':
+                    reltype = 'blocked by'
+                if relation.relation_type == 'blocked':
+                    reltype = 'blocks'
+                relish = rmine.issue.get(relation.issue_id)
+            else:
+                relish = rmine.issue.get(relation.issue_to_id)
+            # Check for unauth -- wtf? See github #20
+            if relish.id == 0:
+                continue
+            # Get the verb right for blocking relationship
+            reltype = relation.relation_type
+            if relation.issue_id != issue.id:
+                if relation.relation_type == 'blocks':
+                    reltype = 'blocked by'
+                if relation.relation_type == 'blocked':
+                    reltype = 'blocks'
+                if relation.relation_type == 'duplicates':
+                    reltype = 'duplicated by'
+                if relation.relation_type == 'precedes':
+                    reltype = 'preceded by'
+                if relation.relation_type == 'follows':
+                    reltype = 'followed by'
+            print('%s %s - %s #%s: %s (%s)') % (reltype,
+                                                relish.project.name,
+                                                relish.tracker.name,
+                                                relish.id,
+                                                relish.subject,
+                                                relation.id)
         for journ in issue.journals:
             print('\n####')
             print('Updated by %s on %s:' % (journ.user.name,
                                             journ.created_on))
-            print(journ.notes)
+            if hasattr(journ, 'notes'):
+                print(journ.notes)
     print('\n')
 
 
@@ -107,6 +139,13 @@ def print_project(rmine, proj, verbose=False):
             pass
     print('\n')
 
+def create_relation(rmine, issue, relissue, reltype):
+    """Creates a new issue relationship between two issues."""
+
+    rmine.issue_relation.create(issue_id=issue,
+                                issue_to_id=relissue,
+                                relation_type=reltype)
+
 
 def issues(args, rmine):
     """Handle issues"""
@@ -132,9 +171,9 @@ def issues(args, rmine):
         if args.query_id:
             qdict['query_id'] = args.query_id
         # Get the issues
-        issues = rmine.issue.filter(**qdict)
+        ishes = rmine.issue.filter(**qdict)
         # This output is kinda lame, but functional for now
-        for issue in issues:
+        for issue in ishes:
             print_issue(rmine, issue, args.verbose, args.oneline)
             if not args.oneline:
                 print('##############')
@@ -174,6 +213,11 @@ def issues(args, rmine):
                 raise RuntimeError('Unknown issue type %s' % args.type)
         # Create the issue
         issue = rmine.issue.create(**idict)
+        # Create a relationship if one was asked for
+        if args.relate_to:
+            create_relation(rmine, issue.id, args.relate_to,
+                            args.relation_type)
+            issue = issue.refresh()
         # Print it out
         print_issue(rmine, issue, args.verbose, args.oneline)
         return
@@ -212,7 +256,13 @@ def issues(args, rmine):
             udict['notes'] = args.notes
 
         for ish in ishs:
-            rmine.issue.update(ish.id, **udict)
+            if udict:
+                rmine.issue.update(ish.id, **udict)
+            else:
+                rmine.issue.get(ish.id)
+            if args.relate_to:
+                create_relation(rmine, ish.id, args.relate_to,
+                                args.relation_type)
             ish = ish.refresh()
             print_issue(rmine, ish, args.verbose, args.oneline)
         return
@@ -254,6 +304,14 @@ def issues(args, rmine):
                         sorted(rmine.query.all(), key=lambda k: k['id'])))
         return
 
+    # delete a relation
+    if args.delete_relation:
+        relation = rmine.issue_relation.get(args.delete_relation)
+        rmine.issue_relation.delete(args.delete_relation)
+        print('Deleted relation %s: %s %s %s' % (relation.id,
+                                                 relation.issue_id,
+                                                 relation.relation_type,
+                                                 relation.issue_to_id))
 
 def projects(args, rmine):
     """Handle projects"""
@@ -307,6 +365,8 @@ def cmd():
                                help='List available issue queries')
     issues_parser.add_argument('--list-statuses', action='store_true',
                                help='List available statuses.')
+    issues_parser.add_argument('--delete_relation', help='Delete a relationship',
+                               type=int, metavar='RELATION_ID')
     # details
     issues_parser.add_argument('--project', help='Filter by or assign to '
                                'project')
@@ -328,7 +388,13 @@ def cmd():
     issues_parser.add_argument('--notes', help='Notes to use when resolving '
                                'or closing an issue')
     issues_parser.add_argument('--query_id', help='Filter by query ID')
-
+    issues_parser.add_argument('--relate_to', help='Create a relationship',
+                               type=int)
+    issues_parser.add_argument('--relation_type', help='Type of relationship '
+                               'to create',
+                               choices=['relates', 'duplicates',
+                                        'blocks', 'blocked',
+                                        'precedes', 'follows'])
     # More options when showing issues
     issues_parser.add_argument('--verbose', action='store_true',
                                help='Show more of the ticket details',
